#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-1wdzlLgu9w12Z0GUoL4lMI
key:                  network-udp-0.0.0-1wdzlLgu9w12Z0GUoL4lMI
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  70056f0c7cc02448a7626449dba13070
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-1wdzlLgu9w12Z0GUoL4lMI
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-Dh7Km049WyYDYDcUpNS5SE
    network-3.1.4.0-57XjnahcYfrBnbtgCzAhJP

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

